tastoids/compare

Given any Tastoid is differentiable with respect to its distance to another, (_either total and partial), it can then be said to impose a total (partial) ordering of any other set of Tastoids.

Akin to gleam/order, a Tastoid is its own ordering

Values

pub fn ordering(
  by differentiator: tastoid.Tastoid(space),
) -> fn(tastoid.Tastoid(space), tastoid.Tastoid(space)) -> order.Order

Return a compare which orders elements by the provided differentiator

Search Document