tastoids/from
Helpful shorthands for quickly making a Tastoid from a like, dislike, ‘meh’ or pass (zero-ish Tastoid)
Values
pub fn dislike(this thing: String) -> tastoid.Tastoid(String)
Coerce any index into a simple Tastoid with a negative sentiment
pub fn like(this thing: String) -> tastoid.Tastoid(String)
Coerce any index into a simple Tastoid with a positive sentiment
pub fn meh(this thing: String) -> tastoid.Tastoid(String)
Coerce any index into a simple Tastoid with a weak negative sentiment.
pub fn pass(this thing: String) -> tastoid.Tastoid(String)
Coerce any index into a simple Tastoid with no sentiment or
contribution (the empty tastoid/Insipoid)
pub fn saw(
this thing: String,
worth weight: Float,
) -> tastoid.Tastoid(String)
Coerce any index into a simple Tastoid with a specific worth
(weight coefficient/multiplier for this’s value)