tastoids/tastoid
Types
pub type Impression {
Yum
Yuck
Meh
Saw(worth: Float)
Pass
}
Constructors
-
YumI liked it, +1
-
YuckI disliked it, -1
-
MehI saw it, and ignoring it is worth ~ -5%
-
Saw(worth: Float)I saw it, ascribing scaling it by weight
-
PassI saw it, and have absolutely no impression
A Tastoid (𝕥) is an element within a subset of Tastoids (𝕋),
constrained to only interact with other tastoids of the same
imbedding indices ( Imbedding(space)).
pub type Tastoid(of) {
Tasteless
Tastoid(taste: taste.Taste(of), cardinality: Int)
}
Constructors
-
TastelessThe empty Tastoid (shared by all index-spaces)
-
Tastoid(taste: taste.Taste(of), cardinality: Int)An impression (or aggregation) of taste e.g. Tastoid(t) -> Tastoids(t, 1)
Values
pub fn from(
thing index: imbedding.Imbedding(space),
) -> Tastoid(imbedding.Imbedding(space))
Coerce a thing of an into a Tastoid, assuming…
- The
thing’s type is theImbedding(space)of theTastoid - The sentiment of that thing is
1.0~ a count of its occurances
In effect, from(thing) is 1 of that thing, as a Tastoid
Example:
"from" |> tastoid.from -> Tastoid(Taste("from", 1.0"), k=1)
42 |> tastoid.from -> Tastoid(Taste(42, 1.0), k=1)
pub fn from_impression(
of index: index,
worth sentiment: Impression,
) -> Tastoid(index)
Given any index (string, Int, or `Set(index)``), coerce it into
a simple Tastoid worth a single contribution (k=1)
pub fn from_sparse_embedding(
values: List(Float),
by indices: List(index),
) -> Tastoid(index)
Coerce a sparse/dense embeddings pair of value and index lists into a conjugated Tastoid worth a single contribution (k=1)
pub fn from_taste(
of taste: taste.Taste(index),
worth impression: Impression,
) -> Tastoid(index)
A tasting of a taste and the impression thereof (e.g. a ‘weight’ or value-multiplier) yield a Tastoid of cardinality (k=1).