tastoids/from
Helpful shorthands for quickly making a Tastoid from a like, dislike, ‘meh’ or pass (zero-ish Tastoid)
Values
pub fn dislike(this index: index) -> tastoid.Tastoid(index)
Coerce any index into a simple Tastoid with a negative sentiment
pub fn like(this index: index) -> tastoid.Tastoid(index)
Coerce any index into a simple Tastoid with a positive sentiment
pub fn meh(this index: index) -> tastoid.Tastoid(index)
Coerce any index into a simple Tastoid with a weak negative sentiment.
pub fn pass(this index: index) -> tastoid.Tastoid(index)
Coerce any index into a simple Tastoid with no sentiment or
contribution (the empty tastoid/Insipoid)
pub fn saw(
this index: index,
worth weight: Float,
) -> tastoid.Tastoid(index)
Coerce any index into a simple Tastoid with a specific worth
(weight coefficient/multiplier for this’s value)